@@ -1,9 +1,9 @@
 /* File: blinkd.h
-   (C) 1998 W. Borgert debacle@debian.org
+   (C) 1998 W. Martin Borgert debacle@debian.org
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
-   the Free Software Foundation; either version 2 of the License, or
+   the Free Software Foundation; either version 3 of the License, or
    (at your option) any later version.
 
    This program is distributed in the hope that it will be useful,
@@ -13,11 +13,10 @@
 
    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
-   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+   Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,
+   MA 02110-1301, USA.
 */
 
-/* @(#) $Id: blinkd.h,v 1.2 1999/06/29 00:32:56 debacle Exp $ */
-
 #define RATE_DEC 0x1F           /* '00111111'B */
 #define RATE_INC (RATE_DEC - 1) /* '00111110'B */
 
